DOCKER_API = 1
FILE_NOT_FOUND = 2
KEYBOARD_INTERRUPT = 3
PARSER_ERROR = 4
PLUGIN_ERROR = 5
PLUGIN_EXCEPTION = 6
VARIABLE_ERROR = 7
TESTER_KEY_ERROR = 8
TEST_KEY_ERROR = 8
TRICOT_EXCEPTION = 9
TRICOT_RUNTIME_ERROR = 10
UNKNOWN = 11
VALIDATION_EXCEPTION = 12
VALIDATOR_ERROR = 13
VALUE_ERROR = 14
RUNTIME_ERROR = 15
CONDITION_FORMAT_ERROR = 16
EXTRACT_EXCEPTION = 17
EXTRACTOR_ERROR = 18
DUPLICATE_ID_ERROR = 19
YAML_SYNTAX_ERROR = 20
MISSING_RESOURCE = 21
VERSION_MISMATCH = 22

LAST_ERROR = 0
VERSION = '1.10.0'
